@@ -21,7 +21,7 @@
 
 from . import _gobject
 
-# TYPE_INVALID defined in gobjectmodule.c
+TYPE_INVALID = _gobject.TYPE_INVALID
 TYPE_NONE = _gobject.type_from_name('void')
 TYPE_INTERFACE = _gobject.type_from_name('GInterface')
 TYPE_CHAR = _gobject.type_from_name('gchar')
@@ -47,36 +47,3 @@ TYPE_GTYPE = _gobject.type_from_name('GType')
 TYPE_STRV = _gobject.type_from_name('GStrv')
 TYPE_VARIANT = _gobject.type_from_name('GVariant')
 TYPE_UNICHAR = TYPE_UINT
-
-# do a little dance to maintain API compatibility
-# as these were origianally defined here, and are
-# now defined in gobjectmodule.c
-G_MINFLOAT = _gobject.G_MINFLOAT
-G_MAXFLOAT = _gobject.G_MAXFLOAT
-G_MINDOUBLE = _gobject.G_MINDOUBLE
-G_MAXDOUBLE = _gobject.G_MAXDOUBLE
-G_MINSHORT = _gobject.G_MINSHORT
-G_MAXSHORT = _gobject.G_MAXSHORT
-G_MAXUSHORT = _gobject.G_MAXUSHORT
-G_MININT = _gobject.G_MININT
-G_MAXINT = _gobject.G_MAXINT
-G_MAXUINT = _gobject.G_MAXUINT
-G_MINLONG = _gobject.G_MINLONG
-G_MAXLONG = _gobject.G_MAXLONG
-G_MAXULONG = _gobject.G_MAXULONG
-G_MININT8 = _gobject.G_MININT8
-G_MAXINT8 = _gobject.G_MAXINT8
-G_MAXUINT8 = _gobject.G_MAXUINT8
-G_MININT16 = _gobject.G_MININT16
-G_MAXINT16 = _gobject.G_MAXINT16
-G_MAXUINT16 = _gobject.G_MAXUINT16
-G_MININT32 = _gobject.G_MININT32
-G_MAXINT32 = _gobject.G_MAXINT32
-G_MAXUINT32 = _gobject.G_MAXUINT32
-G_MININT64 = _gobject.G_MININT64
-G_MAXINT64 = _gobject.G_MAXINT64
-G_MAXUINT64 = _gobject.G_MAXUINT64
-G_MAXSIZE = _gobject.G_MAXSIZE
-G_MAXSSIZE = _gobject.G_MAXSSIZE
-G_MINOFFSET = _gobject.G_MINOFFSET
-G_MAXOFFSET = _gobject.G_MAXOFFSET
